summaryrefslogtreecommitdiff
path: root/libavformat/rtpdec_qdm2.c
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2012-08-05 11:11:04 +0200
committerAnton Khirnov <anton@khirnov.net>2012-08-07 16:00:24 +0200
commit36ef5369ee9b336febc2c270f8718cec4476cb85 (patch)
treed186adbb488e7f002aa894743b1ce0e8925520e6 /libavformat/rtpdec_qdm2.c
parent104e10fb426f903ba9157fdbfe30292d0e4c3d72 (diff)
Replace all CODEC_ID_* with AV_CODEC_ID_*
Diffstat (limited to 'libavformat/rtpdec_qdm2.c')
-rw-r--r--libavformat/rtpdec_qdm2.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavformat/rtpdec_qdm2.c b/libavformat/rtpdec_qdm2.c
index 76b4c5317d..a2ce510d26 100644
--- a/libavformat/rtpdec_qdm2.c
+++ b/libavformat/rtpdec_qdm2.c
@@ -259,14 +259,14 @@ static int qdm2_parse_packet(AVFormatContext *s, PayloadContext *qdm,
return res;
p += res;
/* We set codec_id to CODEC_ID_NONE initially to
* delay decoder initialization since extradata is
* carried within the RTP stream, not SDP. Here,
* by setting codec_id to CODEC_ID_QDM2, we are signalling
* to the decoder that it is OK to initialize. */
- st->codec->codec_id = CODEC_ID_QDM2;
+ st->codec->codec_id = AV_CODEC_ID_QDM2;
}
- if (st->codec->codec_id == CODEC_ID_NONE)
+ if (st->codec->codec_id == AV_CODEC_ID_NONE)
return AVERROR(EAGAIN);
/* subpackets */
@@ -310,7 +310,7 @@ static void qdm2_extradata_free(PayloadContext *qdm)
RTPDynamicProtocolHandler ff_qdm2_dynamic_handler = {
.enc_name = "X-QDM",
.codec_type = AVMEDIA_TYPE_AUDIO,
- .codec_id = CODEC_ID_NONE,
+ .codec_id = AV_CODEC_ID_NONE,
.alloc = qdm2_extradata_new,
.free = qdm2_extradata_free,
.parse_packet = qdm2_parse_packet,
@@ -259,14 +259,14 @@ static int qdm2_parse_packet(AVFormatContext *s, PayloadContext *qdm,
return res;
p += res;
- /* We set codec_id to CODEC_ID_NONE initially to
+ /* We set codec_id to AV_CODEC_ID_NONE initially to
* delay decoder initialization since extradata is
* carried within the RTP stream, not SDP. Here,
@@ -259,14 +259,14 @@ static int qdm2_parse_packet(AVFormatContext *s, PayloadContext *qdm,
* delay decoder initialization since extradata is
* carried within the RTP stream, not SDP. Here,
- * by setting codec_id to CODEC_ID_QDM2, we are signalling
+ * by setting codec_id to AV_CODEC_ID_QDM2, we are signalling
* to the decoder that it is OK to initialize. */